@@ -71,11 +71,9 @@ def get_result_df(py_filename, output_folder, start_date, end_date, para_dict):
     return result_df
 
 
-def plot_equity_curves(py_filename, output_folder, start_date, end_date, para_dict, result_df, subchart_settings, width=None):
+def plot_equity_curves(py_filename, output_folder, start_date, end_date, para_dict, result_df, subchart_settings):
 
-    if not width: width = 950
-
-    app = equity_curves.Plot(py_filename, output_folder, start_date, end_date, para_dict, result_df, generate_filepath, subchart_settings, width)
+    app = equity_curves.Plot(py_filename, output_folder, start_date, end_date, para_dict, result_df, generate_filepath, subchart_settings)
 
     return app
 
