@@ -19,7 +19,7 @@ class Components:
                    options=[{'label': 'Top 20 Net Profit', 'value': 'Top 20 Net Profit'},
                             {'label': 'Top 20 Net Profit to MDD', 'value': 'Top 20 Net Profit to MDD'}, ],
                    style={'border-radius': '5px', 'font-size': '12px', }),
-        style={'padding-left': '12.5px', 'width': '230px'})
+        style={'padding-left': '12.5px', 'width': '280px'})
 
     subchart_dropdown = html.Div(
         dbc.Select(id='subchart_dropdown',
@@ -48,14 +48,14 @@ class Components:
                                                        {'label': 'Win Rate <', 'value': 'win_rate<'},
                                                    ],
                                                    style={'border-radius': '5px', 'font-size': '12px'}),
-                               style={'padding-left': '15px', 'width': '170px'})
+                               style={'padding-left': '15px', 'width': '210px'})
 
     filter_dropdown_disabled = html.Div(id='filter_dropdown',
                                         children=dbc.Select(id='filter_name', disabled=True,
                                                             placeholder="Select Filter",
                                                             style={'border-radius': '5px', 'font-size': '12px',
                                                                    'backgroundColor': 'Gray'}),
-                                        style={'padding-left': '15px', 'width': '170px'})
+                                        style={'padding-left': '15px', 'width': '210px'})
 
     filter_input = dbc.Input(id='filter_input', value=None, size="md", type='text',
                              style={'width': '50px', 'margin-right': '5px', 'border-radius': '3px',
@@ -65,10 +65,10 @@ class Components:
                                       style={'width': '50px', 'margin-right': '5px', 'border-radius': '3px',
                                                'padding': '6px 5px', 'font-size': '12px', 'backgroundColor': 'Gray'})
 
-    add_button_style = {'margin-left': '50px', 'width': '140px', 'backgroundColor': 'blue',
+    add_button_style = {'margin-left': '50px', 'width': '180px', 'backgroundColor': 'blue',
                         'border-radius': '5px', 'text-align': 'center', 'cursor': 'pointer'}
 
-    add_button_style_disabled = {'margin-left': '50px', 'width': '140px', 'color': 'Silver', 'backgroundColor': 'Gray',
+    add_button_style_disabled = {'margin-left': '50px', 'width': '180px', 'color': 'Silver', 'backgroundColor': 'Gray',
                                  'border-radius': '5px', 'text-align': 'center'}
 
 
@@ -76,7 +76,7 @@ class Components:
         chart_bg = self.chart_bg
         fig_line = px.line()
         fig_line.update_layout(plot_bgcolor=chart_bg, paper_bgcolor=chart_bg, margin=dict(l=85, r=60, t=30, b=40),
-                               height=340, font={"color": chart_bg})
+                               height=320, font={"color": chart_bg})
         fig_line.update_xaxes(showline=True, zeroline=False, linecolor='#979A9A', gridcolor=chart_bg)
         fig_line.update_yaxes(showline=True, zeroline=False, linecolor='#979A9A', gridcolor=chart_bg)
 
@@ -121,16 +121,77 @@ class Components:
 
         return checkbox_div
 
+    def update_stat_div(self, period, pct_mean, rise_mean, fall_mean):
+        div = html.Div([
+            html.Div(style={'height': '15px', }),
 
-    def radioitems(self, para_dict, result_df):
-        print(para_dict)
-        print(result_df)
+             # html.Div('Average', style={'text-align': 'left'}),
+             #
+             # html.Div(style={'height': '5px', }),
 
-        for key, options in enumerate(para_dict):
-            print(key, options)
+            dbc.Row([
+                 dbc.Col(width=2),
+                 dbc.Col(str(period[0]) + ' Days',width=2),
+                 dbc.Col(str(period[1]) + ' Days', width=2),
+                 dbc.Col(str(period[2]) + ' Days', width=2),
+                 dbc.Col(str(period[3]) + ' Days', width=2),
+                 dbc.Col(str(period[4]) + ' Days', width=2),
+             ]),
 
+            html.Div(style={'height': '5px', }),
+
+            dbc.Row([
+                 dbc.Col('pct_change', width=2),
+                 dbc.Col(f'{pct_mean[0]}%', width=2),
+                 dbc.Col(f'{pct_mean[1]}%', width=2),
+                 dbc.Col(f'{pct_mean[2]}%', width=2),
+                 dbc.Col(f'{pct_mean[3]}%', width=2),
+                 dbc.Col(f'{pct_mean[4]}%', width=2),
+             ]),
+
+            html.Div(style={'height': '5px', }),
+
+            dbc.Row([
+                 dbc.Col('max_rise', width=2),
+                 dbc.Col(f'{rise_mean[0]}%', width=2),
+                 dbc.Col(f'{rise_mean[1]}%', width=2),
+                 dbc.Col(f'{rise_mean[2]}%', width=2),
+                 dbc.Col(f'{rise_mean[3]}%', width=2),
+                 dbc.Col(f'{rise_mean[4]}%', width=2),
+             ]),
+
+            html.Div(style={'height': '5px', }),
+
+            dbc.Row([
+                 dbc.Col('max_fall', width=2),
+                 dbc.Col(f'{fall_mean[0]}%', width=2),
+                 dbc.Col(f'{fall_mean[1]}%', width=2),
+                 dbc.Col(f'{fall_mean[2]}%', width=2),
+                 dbc.Col(f'{fall_mean[3]}%', width=2),
+                 dbc.Col(f'{fall_mean[4]}%', width=2),
+             ]),
+
+            html.Div(style={'height': '15px', }),
+        ])
+
+        return div
+
+
+    def generate_radioitems(self, para_dict):
         radioitems_div = []
 
+        for i, key in enumerate(para_dict):
+            options = para_dict[key]
+
+            radioitems_div.append(key)
+
+            radioitems_div.append(dcc.RadioItems(
+                id={'type': 'para_radioitems', 'index': i},
+                options=[{'label': k, 'value': k} for k in options],
+            ), )
+
+            radioitems_div.append(html.Div(html.Img(),style={'height':'5px'}))
+
         return radioitems_div
 
 
@@ -320,7 +381,7 @@ class Components:
         fig_line = px.line()
         fig_line.update_xaxes(showline=True, zeroline=False, linecolor='white', gridcolor='rgba(0, 0, 0, 0)')
         fig_line.update_yaxes(showline=True, zeroline=False, linecolor='white', gridcolor='rgba(0, 0, 0, 0)')
-        fig_line.update_layout(plot_bgcolor=self.chart_bg, paper_bgcolor=self.chart_bg, height=340,
+        fig_line.update_layout(plot_bgcolor=self.chart_bg, paper_bgcolor=self.chart_bg, height=320,
                                margin=dict(l=85, r=25, t=10, b=0),
                                showlegend=False,
                                font={"color": "white", 'size': 10.5}, yaxis={'title': 'Equity'},
@@ -363,10 +424,11 @@ class Components:
 
 
     def prepare_df_chart(self, df):     # Chart Data for Chart 2
+        initial_value = df.iloc[0].equity_value
         df_chart = pd.DataFrame()
         df_chart['date'] = pd.to_datetime(df['date'], format='%Y-%m-%d')
         df_chart['close'] = df['close']
-        df_chart['bah'] = df['close'] * (100000 / df_chart.iloc[0].close)
+        df_chart['bah'] = df['close'] * (initial_value / df_chart.iloc[0].close)
         df_chart['equity_value'] = df['equity_value']
         df_chart['action'] = df['action']
         df_chart['volume'] = df['volume']
@@ -539,12 +601,12 @@ class Components:
                     go.Bar(hoverinfo='skip', x=df_chart['date'], y=df_chart[element], showlegend=True,
                            marker_color=line_color, marker_line_color=line_color, name=element),
                 ])
-            fig.update_layout(width=683)
+            fig.update_layout(width=683+187)
         else:
             fig = go.Figure(data=[
                 go.Scatter(mode='lines', hoverinfo='skip', x=df_chart['date'], y=df_chart[element], showlegend=True,
                            line=dict(color=line_color, width=1.5), name=element), ] )
-            fig.update_layout(width=670)
+            fig.update_layout(width=670+187)
         fig.update_layout(plot_bgcolor='#1f2c56', paper_bgcolor='#1f2c56', height=60,
                           margin=dict(l=85, r=50, t=5, b=20),
                           font={"color": "white",'size': 9}, yaxis={'fixedrange': True}, xaxis={'fixedrange': True},
@@ -555,7 +617,7 @@ class Components:
         return fig
 
 
-    def generate_histogram(self, df, period):
+    def generate_histogram(self, df, period, mode):
         chart_bg = self.chart_bg
         col_pct = 'pct_change_' + str(period)
         col_rise = 'max_rise_' + str(period)
@@ -565,7 +627,10 @@ class Components:
         df_his[col_pct] = df_his[col_pct].shift(-1 * period)
         df_his[col_pct] = df_his[col_pct] * 100
         df_his[col_pct] = df_his[col_pct].map(lambda x: round(x, 2))
-        df_his = df_his[df_his['action'] == 'open']
+        if mode == 'backtest':
+            df_his = df_his[df_his['action'] == 'open']
+        else:
+            df_his = df_his[df_his['logic'] == 'trade_logic']
 
         df_his[col_rise] = (df_his['high'].rolling(period).max().shift(-1 * (period)) / df_his['close']) - 1
         df_his[col_fall] = (df_his['low'].rolling(period).min().shift(-1 * (period)) / df_his['close']) - 1
@@ -580,7 +645,7 @@ class Components:
 
         margin = dict(l=5, r=5, t=5, b=5)
         h = 85
-        w = 120
+        w = 140
         f = {"color": "white", 'size': 8}
 
         fig_pct = go.Figure()
@@ -606,3 +671,25 @@ class Components:
 
         return fig_pct, fig_rise, fig_fall
 
+
+    def generate_df_stat(self, df, period):
+        col_pct = 'pct_change_' + str(period)
+        col_rise = 'max_rise_' + str(period)
+        col_fall = 'max_fall_' + str(period)
+        df_his = df.copy()
+        df_his[col_pct] = df_his['close'].pct_change(period)
+        df_his[col_pct] = df_his[col_pct].shift(-1 * period)
+        df_his[col_pct] = df_his[col_pct] * 100
+        df_his[col_pct] = df_his[col_pct].map(lambda x: round(x, 2))
+        df_his = df_his[df_his['logic'] == 'trade_logic']
+
+        df_his[col_rise] = (df_his['high'].rolling(period).max().shift(-1 * (period)) / df_his['close']) - 1
+        df_his[col_fall] = (df_his['low'].rolling(period).min().shift(-1 * (period)) / df_his['close']) - 1
+
+        df_his[col_rise] = df_his[col_rise] * 100
+        df_his[col_fall] = df_his[col_fall] * 100
+
+        df_his[col_rise] = df_his[col_rise].map(lambda x: round(x, 2))
+        df_his[col_fall] = df_his[col_fall].map(lambda x: round(x, 2))
+
+        return round(df_his[col_pct].mean(), 2), round(df_his[col_rise].mean(), 2), round(df_his[col_fall].mean(), 2)
\ No newline at end of file
