@@ -28,7 +28,7 @@ class Plot:
     init = True
 
 
-    def __new__(self, filename, output_folder, start_date, end_date, para_dict, result_df, generate_filepath, settings, width):
+    def __new__(self, filename, output_folder, start_date, end_date, para_dict, result_df, generate_filepath, settings):
 
         chart_bg = self.chart_bg
 
@@ -64,10 +64,12 @@ class Plot:
                         sort_method_dropdown,
                         html.Div(style={'height': '10px', }),
                         html.Div(id='checklist-container',children=checkbox_div),
-                        html.Div('---------------------------------------',style={'margin-left': '15px'}),
+                        html.Div('-----------------------------------------------',style={'margin-left': '15px'}),
                         html.Div('Filters:', style={'margin-left': '15px'}),
                         html.Div(style={'height': '10px', }),
-                        html.Div(id='filter', children=filter_div,style={'padding': '0px 20px', 'font-size': '12px'}),
+                        html.Div(id='filter', children=filter_div,style={'padding': '0px 20px',
+                                                                         'padding-right': '30px',
+                                                                         'font-size': '12px'}),
 
                         dbc.Row([
                             dbc.Col(id='filter_dropdown_div',children=filter_dropdown,width=8),
@@ -120,7 +122,7 @@ class Plot:
                 ])
             ),
 
-        ], style={'width':str(width)+'px','margin':'auto','padding':'0px','color':'white'})
+        ], style={'width':'1200px','margin':'auto','padding':'0px','color':'white'})
 
 
 
@@ -262,7 +264,7 @@ class Plot:
                                 pass
 
                             # Generate Chart 2 after knowing subchart count
-                            fig_line = components.generate_chart_2(df_chart, line_colour, 340 - subchart_count*60)
+                            fig_line = components.generate_chart_2(df_chart, line_colour, 340 - subchart_count*60 - 20)
 
 
 
@@ -283,7 +285,7 @@ class Plot:
 
                             for p in period:
                                 title_list.append(dbc.Col(f'{p} Days',style={'font-size': '12px', 'text-align': 'center'},width=2))
-                                fig_pct, fig_rise, fig_fall = components.generate_histogram(df, p)
+                                fig_pct, fig_rise, fig_fall = components.generate_histogram(df, p, 'backtest')
                                 pct_list.append( dbc.Col(dcc.Graph(figure=fig_pct,config={'displayModeBar': False})
                                                          ,style={'padding':'0'},width=2))
                                 rise_list.append(dbc.Col(dcc.Graph(figure=fig_rise,config={'displayModeBar': False})
